Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1327)

Unified Diff: Source/core/rendering/RenderBlock.cpp

Issue 335963002: Change LayoutState to be stack-allocated (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Fix push function to match old behavior... Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/rendering/RenderBlock.cpp
diff --git a/Source/core/rendering/RenderBlock.cpp b/Source/core/rendering/RenderBlock.cpp
index 806cdf15b023da34a8949ddbcd114b695ea90523..506e33de9f9e609595bd336a6f0f9f12913185cc 100644
--- a/Source/core/rendering/RenderBlock.cpp
+++ b/Source/core/rendering/RenderBlock.cpp
@@ -377,7 +377,7 @@ void RenderBlock::invalidateTreeAfterLayout(const RenderLayerModelObject& invali
// Take care of positioned objects. This is required as LayoutState keeps a single clip rect.
if (TrackedRendererListHashSet* positionedObjects = this->positionedObjects()) {
TrackedRendererListHashSet::iterator end = positionedObjects->end();
- LayoutStateMaintainer statePusher(*this, isTableRow() ? LayoutSize() : locationOffset());
+ LayoutState state(*this, isTableRow() ? LayoutSize() : locationOffset());
for (TrackedRendererListHashSet::iterator it = positionedObjects->begin(); it != end; ++it) {
RenderBox* box = *it;
@@ -1573,8 +1573,8 @@ bool RenderBlock::simplifiedLayout()
{
- // LayoutStateMaintainer needs this deliberate scope to pop before repaint
- LayoutStateMaintainer statePusher(*this, locationOffset());
+ // LayoutState needs this deliberate scope to pop before repaint
+ LayoutState state(*this, locationOffset());
if (needsPositionedMovementLayout() && !tryLayoutDoingPositionedMovementOnly())
return false;

Powered by Google App Engine
This is Rietveld 408576698